#
# spec file for package maven-javadoc-plugin
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "bootstrap"
%bcond_without bootstrap
%else
%bcond_with bootstrap
%endif
%global base_name maven-javadoc-plugin
Version:        3.11.2
Release:        3.1
Summary:        Maven plugin for creating javadocs
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/plugins/maven-javadoc-plugin
Source0:        %{base_name}-%{version}.tar.xz
Source1:        %{base_name}-build.xml
Patch0:         %{base_name}-bootstrap-resources.patch
Patch1:         0001-Be-consistent-about-data-encoding.patch
Patch2:         0002-Make-the-legacyMode-consistent-and-actually-useful.patch
Patch3:         0003-reproducible-from-environment.patch
BuildRequires:  apache-commons-io
BuildRequires:  apache-commons-lang3
BuildRequires:  apache-commons-text
BuildRequires:  atinject
BuildRequires:  fdupes
BuildRequires:  httpcomponents-client
BuildRequires:  httpcomponents-core
BuildRequires:  javapackages-local
BuildRequires:  maven-archiver
BuildRequires:  maven-common-artifact-filters
BuildRequires:  maven-doxia-sink-api
BuildRequires:  maven-doxia-sitetools
BuildRequires:  maven-invoker
BuildRequires:  maven-lib
BuildRequires:  maven-plugin-annotations
BuildRequires:  maven-reporting-api
BuildRequires:  maven-reporting-impl
BuildRequires:  maven-resolver-api
BuildRequires:  maven-resolver-impl
BuildRequires:  maven-resolver-util
BuildRequires:  maven-shared-utils
BuildRequires:  maven-wagon-provider-api
BuildRequires:  objectweb-asm
BuildRequires:  plexus-archiver
BuildRequires:  plexus-interactivity-api
BuildRequires:  plexus-io
BuildRequires:  plexus-languages
BuildRequires:  plexus-utils
BuildRequires:  plexus-xml
BuildRequires:  qdox
BuildRequires:  sisu-inject
BuildRequires:  sisu-plexus
BuildRequires:  slf4j
BuildRequires:  unzip
BuildRequires:  xmvn-install
BuildRequires:  xmvn-resolve
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugins:pom:) >= 40
BuildArch:      noarch
%if %{with bootstrap}
Name:           %{base_name}-bootstrap
BuildRequires:  ant
BuildRequires:  modello >= 2.0.0
%else
Name:           %{base_name}
BuildRequires:  xmvn
BuildRequires:  mvn(org.apache.maven.plugins:maven-compiler-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-jar-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-javadoc-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-resources-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-surefire-plugin)
BuildRequires:  mvn(org.codehaus.modello:modello-maven-plugin)
BuildRequires:  mvn(org.eclipse.sisu:sisu-maven-plugin)
Obsoletes:      %{base_name}-bootstrap
#!BuildRequires: maven-compiler-plugin-bootstrap
#!BuildRequires: maven-jar-plugin-bootstrap
#!BuildRequires: maven-javadoc-plugin-bootstrap
#!BuildRequires: maven-plugin-plugin-bootstrap
#!BuildRequires: maven-resources-plugin-bootstrap
#!BuildRequires: maven-surefire-plugin-bootstrap
%endif

%description
The Maven Javadoc Plugin is a plugin that uses the javadoc tool for
generating javadocs for the specified project.

%if %{without bootstrap}
%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.
%endif

%prep
%setup -q -n %{base_name}-%{version}
%if %{with bootstrap}
cp %{SOURCE1} build.xml
%patch -P 0 -p1
%endif
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1

%pom_remove_dep :::test:

%build
%if %{with bootstrap}
mkdir -p lib
build-jar-repository -s lib \
    apache-commons-lang3 \
    apache-commons-text \
    atinject \
    httpcomponents/httpclient \
    httpcomponents/httpcore \
    maven-archiver/maven-archiver \
    maven-common-artifact-filters/maven-common-artifact-filters \
    maven-doxia/doxia-core \
    maven-doxia/doxia-module-xhtml5 \
    maven-doxia/doxia-sink-api \
    maven-doxia-sitetools/doxia-integration-tools \
    maven-doxia-sitetools/doxia-site-renderer \
    maven-invoker/maven-invoker \
    maven/maven-artifact \
    maven/maven-core \
    maven/maven-model \
    maven/maven-model-builder \
    maven/maven-plugin-api \
    maven/maven-settings \
    maven-plugin-tools/maven-plugin-annotations \
    maven-resolver/maven-resolver-api \
    maven-resolver/maven-resolver-util \
    maven-reporting-api/maven-reporting-api \
    maven-shared-utils/maven-shared-utils \
    maven-wagon/provider-api \
    objectweb-asm/asm \
    org.eclipse.sisu.inject \
    org.eclipse.sisu.plexus \
    plexus/archiver \
    plexus/interactivity-api \
    plexus/io \
    plexus-languages/plexus-java \
    plexus/utils \
    plexus/xml \
    qdox \
    slf4j/api
ant -Dtest.skip=true jar
%else
xmvn --batch-mode --offline \
    -Dmaven.test.skip=true -DmavenVersion=3.5.0 \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    package org.apache.maven.plugins:maven-javadoc-plugin:aggregate
%endif

%{mvn_artifact} pom.xml target/%{base_name}-%{version}.jar

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles

%if %{without bootstrap}
%files javadoc -f .mfiles-javadoc
%endif

%changelog
* Sat Jul 12 2025 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * 0002-Make-the-legacyMode-consistent-and-actually-useful.patch
    + fix the legacy mode so that is behaves really as javadoc 8
    generation
- Modified patches:
  * stale-data-encoding.patch
  - -> 0001-Be-consistent-about-data-encoding.patch
    + rebase and fix the coding style so that it corresponds to
    our PR to the upstream project
  * reproducible-from-environment.patch
  - -> 0003-reproducible-from-environment.patch
    + rebase and make consistent with upstream coding style
* Tue Jun  3 2025 Fridrich Strba <fstrba@suse.com>
- Add dependency on objectweb-asm to build with sisu 0.9.0.M4
* Sun Dec  8 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.11.2
  * New Feature
    + MJAVADOC-814: Ability to split grouped packages over multiple
    lines
  * Improvement
    + MJAVADOC-823: legacyMode keeps using module-info.java
    (-sourcedirectory still use as well as java files input)
  * Task
    + MJAVADOC-822: parameter skippedModules should scale and easier
    to use
* Mon Nov  4 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.11.1
- Version 3.11.1
  * Bug
    + MJAVADOC-820: [REGRESSION] MJAVADOC-787 was merged
    incompletely
  * New Feature
    + MJAVADOC-787: Automatic detection of release option for
    JDK < 9
  * Task
    + MJAVADOC-819: Align archive generation code with Maven Source
    Plugin
    + MJAVADOC-821: Align toolchain discovery code with Maven
    Compiler Plugin
  * Dependency upgrade
    + MJAVADOC-816: Bump org.codehaus.plexus:plexus-java from
    1.2.0 to 1.3.0
    + MJAVADOC-817: Upgrade to Doxia 2.0.0 GA Stack
- Modified patches:
  * maven-javadoc-plugin-bootstrap-resources.patch
    + Regenerate from non-bootstrap build
* Thu Oct  3 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.10.1
- Version 3.10.1
  * Bug
    + MJAVADOC-810: [REGRESSION] MJAVADOC-791 causes forked Maven
    execution fail if any toolchains or settings file isn't
    present
    + MJAVADOC-811: javadoc.bat fails to execute on Windows when
    project is not on drive C and AutoRun is configured
    + MJAVADOC-812: [REGRESSION] maven-javadoc-plugin 3.10.0 creates
    empty JARs
- Version 3.10.0
  * Bug
    + MJAVADOC-560: Clarify outputDirectory, reportOutputDirectory
    in javadoc:javadoc documentation
  * Task
    + MJAVADOC-776: Plugin depends on plexus-container-default,
    which is EOL
    + MJAVADOC-785: Align plugin implementation with
    AbstractMavenReport (maven-reporting-impl)
    + MJAVADOC-807: Simplify IT for MJAVADOC-498
    + MJAVADOC-809: Align Mojo class names
- Version 3.8.0
  * Bug
    + MJAVADOC-603: javadoc:fix failure on JDK10:
    java.lang.ClassNotFoundException: java.sql.Connection
    + MJAVADOC-751: No warnings for localized output
    + MJAVADOC-775: Option 'taglets/taglet/tagletpath' ignored when
    pointing to a JAR
    + MJAVADOC-783: Invalid path when using TagletArtifact and
    TagletPath
    + MJAVADOC-791: maven-javadoc-plugin not working correctly
    together with maven-toolchains-plugin
  * Improvement
    + MJAVADOC-796: Do not follow links for Java 12+
    + MJAVADOC-798: Consider passing user settings when using
    invoker
    + MJAVADOC-802: Set default value of defaultAuthor parameter
    in fix goals to ${user.name}
    + MJAVADOC-803: Add default parameter to force root locale
  * Test
    + MJAVADOC-804: Temporary files are left after test execution
  * Task
    + MJAVADOC-799: Remove inconsistent
    'AbstractFixJavadocMojo#defaultVersion' default value
- Version 3.7.0
  * Bug
    + MJAVADOC-793: java.lang.NullPointerException: Cannot invoke
    "String.length()" because "text" is null
- Version 3.6.3
  * Bug
    + MJAVADOC-682: Reactor builds fail when multiple modules with
    same groupId:artifactId, but different versions
    + MJAVADOC-780: Unit tests create null-null.jar in build root
    directory
  * Improvement
    + MJAVADOC-779: Upgrade maven-plugin parent to 41
  * Task
    + MJAVADOC-782: Align read-only parameters naming with other
    plugins
- Version 3.6.2
  * Bug
    + MJAVADOC-713: Skipping Javadoc reportset leaves empty Javadoc
    link in site
    + MJAVADOC-716: The stale file detection does not work
    + MJAVADOC-726: Maven Java Doc Plugin downloads Log4j-1.2.12
    dependency transitively
    + MJAVADOC-762: createTestRepo in JavaDocReportTest shares state
    + MJAVADOC-774: 3.6.0 release is not reproducible
  * Improvement
    + MJAVADOC-730: Deprecate parameter "old"
- Removed patches:
  * no-override.patch
    + not needed with this version
- Modified patches:
  * maven-javadoc-plugin-bootstrap-resources.patch
    + Regenerate using maven-plugin-plugin 3.15 from non-bootstrap
    build
  * reproducible-from-environment.patch
  * stale-data-encoding.patch
    + adapt to changed context
- Fetch sources from Github using source service
* Tue Sep 24 2024 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * reproducible-from-environment.patch
    + SOURCE_DATE_EPOCH environmental variable triggers reproducible
    use of the maven-javadoc-plugin if it is not requested already
    using the project.build.outputTimestamp option.
* Mon Jun 10 2024 Fridrich Strba <fstrba@suse.com>
- Remove dependency on plexus-metadata-generator,
  plexus-component-metadata and on their dependencies, since there
  is no plexus @Component annotation any more
* Tue Apr  2 2024 Fridrich Strba <fstrba@suse.com>
- Add dependency on plexus-xml where relevant
  * this will be needed for smooth upgrade to plexus-utils 4.0.0
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Jan 26 2024 Fridrich Strba <fstrba@suse.com>
- Require maven-parent >= 40. The maven build will fail with
  anything lower
* Wed Sep 20 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.6.0
  * Bug
    + MJAVADOC-642: Setting maven.javadoc.isoffline seems to have no
    effect
    + MJAVADOC-701: javadoc site is broken for projects that contain
    modules
    + MJAVADOC-733: Alternative doclet page points to an SEO spammy
    page
    + MJAVADOC-742: [REGRESSION] Transitive dependencies of
    docletArtifact missing
    + MJAVADOC-757: Unresolvable link in javadoc tag with value
    ResourcesBundleMojo#getAttachmentClassifier() found in
    ResourcesBundleMojo
    + MJAVADOC-758: IOException --> NullPointerException in
    JavadocUtil.copyResource
    + MJAVADOC-763: JavadocReportTest.testExceptions is broken
    + MJAVADOC-767: javadoc creates invalid --patch-module
    statements
    + MJAVADOC-769: javadoc plugin can not deal with transitive
    filename based modules
  * Improvement
    + MJAVADOC-755: Clean up deprecated and unpreferred methods in
    JavadocUtil
    + MJAVADOC-760: Cleanup dependency declarations as best possible
    + MJAVADOC-770: Allow building javadoc "the old fashioned way"
    after Java 8
  * Task
    + MJAVADOC-743: Drop use of deprecated localRepository mojo
    parameter
    + MJAVADOC-765: Make build pass with Java 20
    + MJAVADOC-772: Refresh download page
  * Dependency upgrade
    + MJAVADOC-761: Update to commons-io 2.13.0
    + MJAVADOC-766: Update plexus-archiver from 4.7.1 to 4.8.0
    + MJAVADOC-771: Upgrade Parent to 40
- Modified patches:
  * maven-javadoc-plugin-bootstrap-resources.patch
    + regenerate in cycle
  * no-override.patch
  * stale-data-encoding.patch
    + rediff to changed line-endings
* Wed Sep 20 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.5.0
  * Bug
    + MJAVADOC-696: Invalid anchors in Javadoc and plugin mojo
    + MJAVADOC-700: Plugin duplicates classes in Java 8 all-classes
    lists
    + MJAVADOC-702: javadoc site creation ignores configuration
    parameters
  * Improvement
    + MJAVADOC-685: Deprecate parameter "stylesheet"
    + MJAVADOC-721: Parse stderr output and suppress informational
    lines
    + MJAVADOC-729: Link to Javadoc references from JDK 17
    + MJAVADOC-731: Migrate components to JSR 330, get rid of
    maven-artifact-transfer, update to parent 37
  * Task
    + MJAVADOC-712: Remove remains of org.codehaus.doxia.sink.Sink
  * Dependency upgrade
    + MJAVADOC-711: Upgrade plugins in ITs
    + MJAVADOC-714: Upgrade to Maven 3.2.5
    + MJAVADOC-719: Update Maven Archiver to 3.6.0
    + MJAVADOC-723: Upgrade Maven Reporting API to 3.1.1/Complete
    with Maven Reporting Impl 3.2.0
    + MJAVADOC-738: Upgrade commons-text to 1.10.0
    + MJAVADOC-740: Upgrade Parent to 39
    + MJAVADOC-741: Upgrade plugins and components
- Modified patches:
  * maven-javadoc-plugin-bootstrap-resources.patch
    + regenerate in cycle
  * stale-data-encoding.patch
    + rediff to changed context
- Added patch:
  * no-override.patch
    + allow building with older version of maven-reporting-api
- Removed patch:
  * maven-javadoc-plugin-ioexception.patch
    + not necessary with this version
* Tue Oct 25 2022 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * maven-javadoc-plugin-ioexception.patch
    + allow building with wider range of plexus-utils versions,
    including the 3.5.0 that does not declare IOException as
    thrown in functions where it is actually not thrown.
* Fri May 13 2022 Fridrich Strba <fstrba@suse.com>
- Fix build with modello 2.0.0
* Mon Mar 14 2022 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * stale-data-encoding.patch
    + use the same encoding when writing and getting the stale data
    + fixes build with utf-8 sources on non utf-8 platforms
* Fri Mar 11 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.3.2
  * fixing several NPE errors and using new
    maven-reporting-{api,impl}
- Removed patches:
  * 0001-Port-to-current-plexus-utils.patch
  * reproducible-footer.patch
    + not needed with the upstream code
- Modified patch:
  * maven-javadoc-plugin-bootstrap-resources.patch
    + regenerate the resources to correspond to the new version
* Tue May 11 2021 Fridrich Strba <fstrba@suse.com>
- Do not build against the legacy guava20 package any more
* Wed Mar 11 2020 Fridrich Strba <fstrba@suse.com>
- Fix build with doxia 1.9.x
* Sun Nov 24 2019 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 3.1.1
- Modified patch:
  * maven-javadoc-plugin-bootstrap-resources.patch
    + Regenerate patch from the non-bootstrap build
* Thu Nov 21 2019 Fridrich Strba <fstrba@suse.com>
- Fix build with maven-invoker-3.0.1 that has a new dependency
  on maven-shared-utils
* Mon Oct  7 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible-footer.patch to override build date (boo#1047218)
* Sat Apr  6 2019 Jan Engelhardt <jengelh@inai.de>
- Spruce up summary to not just repeat the name.
* Wed Apr  3 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-jar-plugin 3.0.1
- Generate and customize ant build.xml file to use with the
  bootstrap variang
- Create as a multibuild package to allow bootstrapping
- Added patch:
  * maven-javadoc-plugin-bootstrap-resources.patch
    + For the bootstrap version, add pre-generated resources that
    need maven-plugin-plugin and maven to be generated at build
    time
